@@ -8,13 +8,13 @@ use Carp;
 use Inline (
         C => "DATA",
         ($ENV{LIBUSB_LIBDIR}
-            ? ( LIBS => "-L$ENV{LIBUSB_LIBDIR} " .
-                        ($^O eq 'MSWin32' ? '-llibusb' : '-lusb') )
+            ? ( LIBS => "-L\"$ENV{LIBUSB_LIBDIR}\" " .
+                        ($^O eq 'MSWin32' ? ' -llibusb -L\"$ENV{WINDDK}\\lib\\crt\\i386\" -lmsvcrt ' : '-lusb') )
             : ( LIBS => '-lusb', )
         ),
-        ($ENV{LIBUSB_INCDIR} ? ( INC => "-I$ENV{LIBUSB_INCDIR}" ) : () ),
+        ($ENV{LIBUSB_INCDIR} ? ( INC => "-I\"$ENV{LIBUSB_INCDIR}\"" ) : () ),
         NAME => 'Device::USB',
-        VERSION => '0.26',
+        VERSION => '0.30',
    );
 
 Inline->init();
@@ -45,11 +45,11 @@ Device::USB - Use libusb to access USB devices.
 
 =head1 VERSION
 
-Version 0.26
+Version 0.30
 
 =cut
 
-our $VERSION='0.26';
+our $VERSION='0.30';
 
 
 =head1 SYNOPSIS
@@ -212,7 +212,7 @@ Any other values are forced to the nearest endpoint.
 sub debug_mode
 {
     my ($class, $level) = @_;
-    
+
     lib_debug_mode( $level );
     return;
 }
@@ -476,6 +476,12 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Device::USB>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
+=head1 FOR MORE INFORMATION
+
+The project is hosted at Google Code L<http://code.google.com/p/perl-device-usb/>.
+More information on the project, including installation help is avaliable on the
+Wiki.
+
 =head1 LIMITATIONS
 
 So far, this module has only been tested on Linux. It should work on any
@@ -498,7 +504,8 @@ Thanks to Josep Monés Teixidor for fixing the C<bInterfaceClass> bug.
 Thanks to Mike McCauley for support of C<usb_get_driver_np> and
 C<usb_detach_kernel_driver_np>.
 
-Thanks to Vadim Mikhailov for fixing a compile problem with VC6 on Windows.
+Thanks to Vadim Mikhailov for fixing a compile problem with VC6 on Windows
+and then chipping in again for VS 2005 on Windows.
 
 Thanks to John R. Hogheruis for information about modifying the Inline
 parameters for compiling with Strawberry Perl on Windows.
@@ -508,7 +515,7 @@ interrupt_read.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2008 Houston Perl Mongers
+Copyright 2006-2009 Houston Perl Mongers
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -525,6 +532,11 @@ __C__
 
 static unsigned debugLevel = 0;
 
+unsigned DeviceUSBDebugLevel()
+{
+    return debugLevel;
+}
+
 void libusb_init()
 {
     usb_init();
@@ -557,7 +569,7 @@ int libusb_close(void *dev)
 
 int libusb_set_configuration(void *dev, int configuration)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_set_configuration( %d )\n", configuration );
     }
@@ -566,7 +578,7 @@ int libusb_set_configuration(void *dev, int configuration)
 
 int libusb_set_altinterface(void *dev, int alternate)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_set_altinterface( %d )\n", alternate );
     }
@@ -575,7 +587,7 @@ int libusb_set_altinterface(void *dev, int alternate)
 
 int libusb_clear_halt(void *dev, unsigned int ep)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_clear_halt( %d )\n", ep );
     }
@@ -590,7 +602,7 @@ int libusb_reset(void *dev)
 int libusb_get_driver_np(void *dev, int interface, char *name, unsigned int namelen)
 {
     int ret = 0;
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_get_driver_np( %d )\n", interface );
     }
@@ -605,7 +617,7 @@ int libusb_get_driver_np(void *dev, int interface, char *name, unsigned int name
 
 int libusb_detach_kernel_driver_np(void *dev, int interface)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_detach_kernel_driver_np( %d )\n", interface );
     }
@@ -618,7 +630,7 @@ int libusb_detach_kernel_driver_np(void *dev, int interface)
 
 int libusb_claim_interface(void *dev, int interface)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_claim_interface( %d )\n", interface );
     }
@@ -627,7 +639,7 @@ int libusb_claim_interface(void *dev, int interface)
 
 int libusb_release_interface(void *dev, int interface)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_release_interface( %d )\n", interface );
     }
@@ -641,7 +653,7 @@ void libusb_control_msg(void *dev, int requesttype, int request, int value, int
 
     Inline_Stack_Vars;
 
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_control_msg( %#04x, %#04x, %#04x, %#04x, %p, %d, %d )\n",
             requesttype, request, value, index, bytes, size, timeout
@@ -649,7 +661,7 @@ void libusb_control_msg(void *dev, int requesttype, int request, int value, int
         /* maybe need to add support for printing the bytes string. */
     }
     retval = usb_control_msg((usb_dev_handle *)dev, requesttype, request, value, index, bytes, size, timeout);
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "\t => %d\n",retval );
     }
@@ -678,7 +690,7 @@ void libusb_control_msg(void *dev, int requesttype, int request, int value, int
 
 int libusb_get_string(void *dev, int index, int langid, char *buf, size_t buflen)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_get_string( %d, %d, %p, %u )\n",
             index, langid, buf, buflen
@@ -689,7 +701,7 @@ int libusb_get_string(void *dev, int index, int langid, char *buf, size_t buflen
 
 int libusb_get_string_simple(void *dev, int index, char *buf, size_t buflen)
 {
-    if(debugLevel)
+    if(DeviceUSBDebugLevel())
     {
         printf( "libusb_get_string_simple( %d, %p, %u )\n",
             index, buf, buflen
@@ -866,7 +878,7 @@ static SV* build_interface( struct usb_interface_descriptor* inter )
     return sv_bless( newRV_noinc( (SV*)hash ),
         gv_stashpv( "Device::USB::DevInterface", 1 )
     );
-} 
+}
 
 /*
  * Given a pointer to an array of usb_interface structs, create a
